uploadSourceSheetTitle property

String get uploadSourceSheetTitle

Title of the bottom sheet that appears when the user taps the Upload FAB and has to choose between the photo picker and the generic file picker.

Implementation

String get uploadSourceSheetTitle;