MediaThumbnails class

Two JPEG variants produced from a source media file.

Constructors

MediaThumbnails({required Uint8List thumb, required Uint8List preview})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
preview Uint8List
~1024px wide JPEG. Suitable for full-screen previews.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumb Uint8List
~256px wide JPEG. Suitable for grid tiles.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited